@@ -12,7 +12,7 @@
 #' # location parameters l = 0.25 and u = .75, and shape
 #' # parameters a = 5 and b = 3. To compute the first four
 #' # raw, central, and standardized moments of this distrubution using
-#' # \code{betamoments()}:
+#' # betamoments():
 #' betamoments(a = 5, b = 3, l = .25, u = .75,
 #' types = c("raw", "central", "standardized"), orders = 4)
 #' @references Hanson, B. A (1991). Method of Moments Estimates for the Four-Parameter Beta Compound Binomial Model and the Calculation of Classification Consistency Indexes. American College Testing Research Report Series.
@@ -55,9 +55,9 @@ betamoments <- function(a, b, l = 0, u = 1, types = c("raw", "central", "standar
 #'
 #' @description Computes Raw, Central, or Standardized moment properties of a vector of observed scores.
 #' @param x A vector of values, the distribution of which moments are to be calculated.
-#' @param type A character vector determining which moment-types are to be calculated. Permissible values are "raw", "central", and "standardized".
+#' @param type A character vector determining which moment-types are to be calculated. Permissible values are \code{"raw"}, \code{"central"}, and \code{"standardized"}.
 #' @param orders The number of moment-orders to be calculated for each of the moment-types.
-#' @param correct Whether to include bias correction in estimation of orders. Default is TRUE.
+#' @param correct Whether to include bias correction in estimation of orders. Default is \code{TRUE}.
 #' @return A list of moment types, each a list of moment orders.
 #' @examples
 #' # Generate some fictional data. Say, 100 individuals take a test with a
@@ -230,12 +230,12 @@ dBetaMS <- function(x, mean, var = NULL, sd = NULL) {
 
 #' Quantile Containing Specific Proportion of the Distribution, Given a Specific Probability of the Standard Beta PDD with Specific Mean and Variance or Standard Deviation.
 #'
-#' @description Calculates the quantile corresponding to a specific probability of some observation falling within the [0, x] (LT = TRUE) or [x, 1] (LT = FALSE) interval under the Standard Beta probability density distribution with defined mean and variance or standard deviation.
+#' @description Calculates the quantile corresponding to a specific probability of some observation falling within the [0, x] (\code{lt = TRUE}) or [x, 1] (\code{lt = FALSE}) interval under the Standard Beta probability density distribution with defined mean and variance or standard deviation.
 #' @param p A value of probability marking the point of the Y-axis to correspond to the X-axis.
 #' @param mean The mean of the target Standard Beta probability density distribution.
 #' @param var The variance of the target Standard Beta probability density distribution.
 #' @param sd The standard deviation of the target Standard Beta probability density distribution.
-#' @param lt Logical. Specifies which end of the tail for which to calculate quantile. Default is TRUE (meaning, find q for lower tail.)
+#' @param lt Logical. Specifies which end of the tail for which to calculate quantile. Default is \code{TRUE} (meaning, find q for lower tail.)
 #' @return A numeric value representing the quantile for which the specified proportion of observations fall within.
 #' @examples
 #' # To compute the quantile at a specific point (e.g., .5) along the Standard
@@ -274,7 +274,7 @@ rBetaMS <- function(n, mean, var = NULL, sd = NULL) {
 #' Coordinate Generation for Marking an Area Under the Curve for the Beta Probability Density Distribution.
 #'
 #' @description Plotting tool, producing a two-column matrix with values of \code{y} corresponding to locations on \code{x}. Useful for shading areas under the curve when tracing the line for the Standard Beta probability density function.
-#' @param from The point of the x-axis from where to start producing y-density values.
+#' @param from The point of the \code{x}-axis from where to start producing \code{y}-density values.
 #' @param to The point of the x-axis to where y-density values are to be produced.
 #' @param by The resolution (or spacing) at which to produce y-density values.
 #' @param alpha The Alpha shape-parameter value for the Standard Beta probability density distribution.
@@ -306,17 +306,17 @@ Beta.gfx.poly.pdf <- function(from, to, by, alpha, beta, l = 0, u = 1) {
 
 #' Coordinate Generation for Marking an Area Under the Curve for the Beta Quantile Density Distribution.
 #'
-#' @description Plotting tool, producing a two-column matrix with values of \code{y} corresponding to locations on \code{x}. Useful for shading areas under the curve when tracing the line for the Standard Beta probability density function.
-#' @param from The point of the x-axis from where to start producing y-density values.
-#' @param to The point of the x-axis to where y-density values are to be produced.
-#' @param by The resolution (or spacing) at which to produce y-density values.
-#' @param alpha The Alpha shape-parameter value for the Standard Beta probability density distribution.
-#' @param beta The Beta shape-parameter fort he Standard Beta probability density distribution.
+#' @description Plotting tool, producing a two-column matrix with values of \code{y} corresponding to locations on \code{x}. Useful for shading areas under the curve when tracing the line for the Standard Beta probability quantile function.
+#' @param from The point of the \code{x}-axis from where to start producing \code{y}-quantile values.
+#' @param to The point of the \code{x}-axis to where \code{y}-quantile values are to be produced.
+#' @param by The resolution (or spacing) at which to produce \code{y}-density values.
+#' @param alpha The Alpha shape-parameter value for the Standard Beta probability distribution.
+#' @param beta The Beta shape-parameter for the Standard Beta probability distribution.
 #' @param l The lower-bound location parameter of the Beta distribution.
 #' @param u The upper-bound location parameter of the Beta distribution.
-#' @return A two-column matrix with density-values of y to plot against corresponding location values of x.
+#' @return A two-column matrix with quantile-values of \code{y} to plot against corresponding location values of \code{x}.
 #' @examples
-#' # To box in an area under a four-parameter beta quantle distribution with
+#' # To box in an area under a four-parameter beta quantile distribution with
 #' # location parameters l = .25 and u = 75, and shape parameters
 #' # alpha = 5 and beta = 3, from .4 to .6:
 #' plot(NULL, xlim = c(0, 1), ylim = c(0, 1))
@@ -339,17 +339,17 @@ Beta.gfx.poly.qdf <- function(from, to, by, alpha, beta, l = 0, u = 1) {
 
 #' Coordinate Generation for Marking an Area Under the Curve for the Beta Cumulative Probability Density Distribution.
 #'
-#' @description Plotting tool, producing a two-column matrix with values of \code{y} corresponding to locations on \code{x}. Useful for shading areas under the curve when tracing the line for the Standard Beta probability density function.
-#' @param from The point of the x-axis from where to start producing y-density values.
-#' @param to The point of the x-axis to where y-density values are to be produced.
-#' @param by The resolution (or spacing) at which to produce y-density values.
-#' @param alpha The Alpha shape-parameter value for the Standard Beta probability density distribution.
-#' @param beta The Beta shape-parameter fort he Standard Beta probability density distribution.
+#' @description Plotting tool, producing a two-column matrix with values of \code{y} corresponding to locations on \code{x}. Useful for shading areas under the curve when tracing the line for the Standard Beta cumulative probability function.
+#' @param from The point of the \code{x}-axis from where to start producing \code{y}-density values.
+#' @param to The point of the \code{x}-axis to where \code{y}-density values are to be produced.
+#' @param by The resolution (or spacing) at which to produce \code{y}-density values.
+#' @param alpha The Alpha shape-parameter value for the Standard Beta cumulative probability distribution.
+#' @param beta The Beta shape-parameter fort he Standard Beta cumulative probability distribution.
 #' @param l The lower-bound location parameter of the Beta distribution.
 #' @param u The upper-bound location parameter of the Beta distribution.
-#' @return A two-column matrix with density-values of y to plot against corresponding location values of x.
+#' @return A two-column matrix with cumulative probability-values of y to plot against corresponding location values of \code{x}.
 #' @examples
-#' # To box in an area under a four-parameter beta cumulative distribution with
+#' # To box in an area under a four-parameter Beta cumulative distribution with
 #' # location parameters l = .25 and u = 75, and shape parameters
 #' # alpha = 5 and beta = 3, from .4 to .6:
 #' plot(NULL, xlim = c(0, 1), ylim = c(0, 1))
@@ -372,9 +372,9 @@ Beta.gfx.poly.cdf <- function(from, to, by, alpha, beta, l = 0, u = 1) {
 
 #' Most Likely True Alpha Value Given Observed Outcome.
 #'
-#' @description Given a fitted Standard Distribution, return the Alpha value where the observed mean becomes the mode.
-#' @param a Observed alpha value for fitted Standard Beta PDD.
-#' @param b Observed beta value for fitted Standard Beta PDD.
+#' @description Given a fitted Standard (two-parameter) Beta Distribution, return the alpha shape-parameter value where the observed mean becomes the mode.
+#' @param a Observed alpha-parameter value for fitted Standard Beta PDD.
+#' @param b Observed beta-parameter value for fitted Standard Beta PDD.
 #' @param x Observed proportion-correct outcome.
 #' @param n Test-length.
 #' @return The Alpha shape-parameter value for the Standard Beta probability density distribution where the observed mean is the expected mode.
@@ -396,9 +396,9 @@ MLA <- function(a, b, x = NULL, n = NULL) {
 
 #' Most Likely True Beta Value Given Observed Outcome.
 #'
-#' @description Assuming a prior standard Beta distribution, return the Beta value where the observed mean becomes the mode.
-#' @param a Observed alpha value for fitted Standard Beta PDD.
-#' @param b Observed beta value for fitted Standard Beta PDD.
+#' @description Assuming a prior standard (two-parameter) Beta Distribution, return the beta shape-parameter value where the observed mean becomes the mode.
+#' @param a Observed alpha-parameter value for fitted Standard Beta PDD.
+#' @param b Observed beta-parameter value for fitted Standard Beta PDD.
 #' @param x Observed proportion-correct outcome.
 #' @param n Test-length.
 #' @examples
@@ -421,7 +421,7 @@ MLB <- function(a, b, x = NULL, n = NULL) {
 
 #' Most Likely Mean of the Standard Beta PDD, Given that the Observation is Considered the Most Likely Observation of the Standard Beta PDD (i.e., Mode).
 #'
-#' @description Assuming a prior standard Beta distribution, returns the expected mean of the distribution under the assumption that the observed value is the most likely value of the distribution.
+#' @description Assuming a prior Standard (two-parameter) Beta Distribution, returns the expected mean of the distribution under the assumption that the observed value is the most likely value of the distribution.
 #' @param a Observed alpha value for fitted Standard Beta PDD.
 #' @param b Observed beta value for fitted Standard Beta PDD.
 #' @param x Observed proportion-correct outcome.
@@ -452,7 +452,7 @@ MLM <- function(a, b, x = NULL, n = NULL) {
 #' @param u The second (upper) location parameter.
 #' @param alpha The first shape parameter.
 #' @param beta The second shape parameter.
-#' @return The value for the probability density at specified values of X.
+#' @return The value for the probability density at specified values of \code{x}.
 #' @examples
 #' # Assume some variable follows a four-parameter beta distribution with
 #' # location parameters l = 0.25 and u = .75, and shape
@@ -475,13 +475,13 @@ dBeta.4P <- function(x, l, u, alpha, beta) {
 
 #' Random Number Generation under the Four-Parameter Beta Probability Density Distribution.
 #'
-#' @description Function for generating random numbers from a specified four-parameter beta distribution.
+#' @description Function for generating random numbers from a specified Four-Parameter Beta Distribution.
 #' @param n Number of draws.
 #' @param l The first (lower) location parameter.
 #' @param u The second (upper) location parameter.
 #' @param alpha The first shape parameter.
 #' @param beta The second shape parameter.
-#' @return A vector with length \code{n} of random values drawn from the four-parameter beta distribution.
+#' @return A vector with length \code{n} of random values drawn from the Four-Parameter Beta Distribution.
 #' @examples
 #' # Assume some variable follows a four-parameter beta distribution with
 #' # location parameters l = 0.25 and u = .75, and shape
@@ -495,13 +495,13 @@ rBeta.4P <- function(n, l, u, alpha, beta) {
 
 #' Cumulative Probability Function under the Four-Parameter Beta Probability Density Distribution.
 #'
-#' @description Function for calculating the proportion of observations up to a specifiable quantile under the four-parameter beta distribution.
+#' @description Function for calculating the proportion of observations up to a specifiable quantile under the Four-Parameter Beta Distribution.
 #' @param q The quantile or a vector of quantiles for which the proportion is to be calculated.
 #' @param l The first (lower) location parameter.
 #' @param u The second (upper) location parameter.
 #' @param alpha The first shape parameter.
 #' @param beta The second shape parameter.
-#' @param lt Whether the proportion to be calculated is to be under the lower or upper tail. Default is TRUE (lower tail).
+#' @param lt Whether the proportion to be calculated is to be under the lower or upper tail. Default is \code{TRUE} (lower tail).
 #' @return A vector of proportions of observations falling under specified quantiles under the four-parameter beta distribution.
 #' @examples
 #' # Assume some variable follows a four-parameter beta distribution with
@@ -524,15 +524,15 @@ pBeta.4P <- function(q, l, u, alpha, beta, lt = TRUE) {
   )
 }
 
-#' Quantile Given Probability Under the Four-Parameter Beta Probability Density Distribution.
+#' Quantile Given Probability Under the Four-Parameter Beta Distribution.
 #'
-#' @description Function for calculating the quantile (i.e., value of x) for a given proportion (i.e., the value of y) under the four-parameter beta distribution.
-#' @param p A vector (or single value) of proportions or probabilities for which the corresponding value of x (i.e., the quantiles) are to be calculated.
+#' @description Function for calculating the quantile (i.e., value of \code{x}) for a given proportion (i.e., the value of \code{y}) under the Four-Parameter Beta Distribution.
+#' @param p A vector (or single value) of proportions or probabilities for which the corresponding value of \code{x} (i.e., the quantiles) are to be calculated.
 #' @param l The first (lower) location parameter.
 #' @param u The second (upper) location parameter.
 #' @param alpha The first shape parameter.
 #' @param beta The second shape parameter.
-#' @param lt Whether the quantile(s) to be calculated is to be under the lower or upper tail. Default is TRUE (lower tail).
+#' @param lt Logical. Whether the quantile(s) to be calculated is to be under the lower or upper tail. Default is \code{TRUE} (lower tail).
 #' @return A vector of quantiles for specified probabilities or proportions of observations under the four-parameter beta distribution.
 #' @examples
 #' # Assume some variable follows a four-parameter beta distribution with
@@ -577,8 +577,88 @@ Beta.4p.fit <- function(scores) {
   r <- 6 * (g4 - g3^2 - 1) / (6 + 3 * g3^2 - 2 * g4)
   a <- r / 2 * (1 + sqrt(1 - ((24 * (r + 1)) / ((r + 2) * (r + 3) * g4 - 3 * (r - 6) * (r + 1)))))
   b <- r / 2 * (1 - sqrt(1 - ((24 * (r + 1)) / ((r + 2) * (r + 3) * g4 - 3 * (r - 6) * (r + 1)))))
-  l <- m1 - ((a * sqrt(s2 * (a + b + 1))) / sqrt(a * b))
-  u <- m1 + ((b * sqrt(s2 * (a + b + 1))) / sqrt(a * b))
-  return(list("alpha" = a, "beta" = b, "l" = l, "u" = u))
+  l <- m1 - ((a * base::sqrt(s2 * (a + b + 1))) / base::sqrt(a * b))
+  u <- m1 + ((b * base::sqrt(s2 * (a + b + 1))) / base::sqrt(a * b))
+  return(base::list("alpha" = a, "beta" = b, "l" = l, "u" = u))
 }
 
+#' An implementation of the Beta-density Compound Cumulative-Binomial Distribution.
+#'
+#' @description The Beta Compound Binomial distribution: The product of the four-parameter Beta probability density function and the binomial cumulative probability mass function. Used in the Livingston and Lewis approach to classification accuracy and consistency, the output can be interpreted as the population density of passing scores produced at "x" (a value of true-score).
+#' @param x x-axis input for which \code{p} (proportion or probability) is to be computed.
+#' @param l The lower-bound of the four-parameter Beta distribution.
+#' @param u The upper-bound of the four-parameter Beta distribution.
+#' @param a The alpha shape-parameter of the Beta distribution.
+#' @param b The beta shape-parameter of the Beta distribution.
+#' @param n The number of trials for the Binomial distribution.
+#' @param c The "true-cut" (proportion) of on the Binomial distribution.
+#' @param lower.tail Logical. Whether to compute the lower or upper tail of the Binomial distribution. Default is \code{FALSE} (i.e., upper tail).
+#' @references Hanson, Bradley A. (1991). Method of Moments Estimates for the Four-Parameter Beta Compound Binomial Model and the Calculation of Classification Consistency Indexes.American College Testing Research Report Series.
+#' @references Livingston, Samuel A. and Lewis, Charles. (1995). Estimating the Consistency and Accuracy of Classifications Based on Test Scores. Journal of Educational Measurement, 32(2).
+#' @references Lord, Frederic M. (1965). A Strong True-Score Theory, With Applications. Psychometrika, 30(3).
+#' @examples
+#' # Given a four-parameter Beta distribution with parameters l = 0.25, u = 0.75,
+#' # alpha = 5, and beta = 3, and a Binomial error distribution with number of
+#' # trials (n) = 10 and a cutoff-point (c) at 50% correct (i.e., proportion correct
+#' # of 0.5), the population density of passing scores produced at true-score
+#' # (x) = 0 can be calculated as:
+#' dBeta.pBinom(x = 0.5, l = 0.25, u = 0.75, a = 5, b = 3, n = 10, c = 0.5)
+#'
+#' # Conversely, the density of failing scores produced at x can be calculated
+#' # by passing the additional argument "lower.tail = TRUE" to the function.
+#' # That is:
+#' dBeta.pBinom(x = 0.5, l = 0.25, u = 0.75, a = 5, b = 3, n = 10, c = 0.5, lower.tail = TRUE)
+#'
+#' #By integration, the population proportion of (e.g.) passing scores in some
+#' #region of the true-score distribution (e.g. between 0.25 and 0.5) can be
+#' #calculated as:
+#' integrate(function(x) { dBeta.pBinom(x, 0.25, .75, 5, 3, 10, 0.5) }, lower = 0.25, upper = 0.5)
+#' @export
+dBeta.pBinom <- function(x, l, u, a, b, n, c, lower.tail = FALSE) {
+  if (!lower.tail) {
+    (1 / beta(a, b)) *
+    dBeta.4P(x, l, u, a, b) * stats::pbinom(n * c, n, x, lower.tail = lower.tail)
+  } else {
+    dBeta.4P(x, l, u, a, b) * (1 - stats::pbinom(n * c, n, x, lower.tail = lower.tail))
+  }
+}
+
+#' An implementation of the Beta-density Compound Cumulative-Beta Distribution.
+#'
+#' @description The Beta Compound Beta distribution: The product of the four-parameter Beta probability density function and the beta cumulative probability function. Used in the Livingston and Lewis approach to classification accuracy and consistency, the output can be interpreted as the population density of passing scores produced at "x" (a value of true-score).
+#' @param x x-axis input for which \code{p} (proportion or probability) is to be computed.
+#' @param l The lower-bound of the four-parameter Beta distribution.
+#' @param u The upper-bound of the four-parameter Beta distribution.
+#' @param a The alpha shape-parameter of the Beta density distribution.
+#' @param b The beta shape-parameter of the Beta density distribution.
+#' @param n The number of trials for the Beta cumulative probability distribution.
+#' @param c The "true-cut" (proportion) of on the Beta cumulative probability distribution.
+#' @param lower.tail Logical. Whether to compute the lower or upper tail of the Beta cumulative probability distribution. Default is \code{FALSE} (i.e., upper tail).
+#' @references Hanson, Bradley A. (1991). Method of Moments Estimates for the Four-Parameter Beta Compound Binomial Model and the Calculation of Classification Consistency Indexes.American College Testing Research Report Series.
+#' @references Livingston, Samuel A. and Lewis, Charles. (1995). Estimating the Consistency and Accuracy of Classifications Based on Test Scores. Journal of Educational Measurement, 32(2).
+#' @references Lord, Frederic M. (1965). A Strong True-Score Theory, With Applications. Psychometrika, 30(3).
+#' @examples
+#' # Given a four-parameter Beta distribution with parameters l = 0.25, u = 0.75,
+#' # alpha = 5, and beta = 3, and a Beta error distribution with number of
+#' # trials (n) = 10 and a cutoff-point (c) at 50% correct (i.e., proportion correct
+#' # of 0.5), the population density of passing scores produced at true-score
+#' # (x) = 0.5 can be calculated as:
+#' dBeta.pBeta(x = 0.5, l = 0.25, u = 0.75, a = 5, b = 3, n = 10, c = 0.5)
+#'
+#' # Conversely, the density of failing scores produced at x can be calculated
+#' # by passing the additional argument "lower.tail = TRUE" to the function.
+#' # That is:
+#' dBeta.pBeta(x = 0.5, l = 0.25, u = 0.75, a = 5, b = 3, n = 10, c = 0.5, lower.tail = TRUE)
+#'
+#' # By integration, the population proportion of (e.g.) passing scores in some
+#' # region of the true-score distribution (e.g. between 0.25 and 0.5) can be
+#' # calculated as:
+#' integrate(function(x) { dBeta.pBeta(x, 0.25, .75, 5, 3, 10, 0.5) }, lower = 0.25, upper = 0.5)
+#' @export
+dBeta.pBeta <- function(x, l, u, a, b, n, c, lower.tail = FALSE) {
+  if(!lower.tail) {
+    dBeta.4P(x, l, u, a, b) * stats::pbeta(c, x * n, (1 - x) * n, lower.tail = FALSE)
+  } else {
+    dBeta.4P(x, l, u, a, b) * (1 - stats::pbeta(c, x * n, (1 - x) * n, lower.tail = FALSE))
+  }
+}
